pm4py.evaluation.precision package
==================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.evaluation.precision.variants

Submodules
----------

pm4py.evaluation.precision.evaluator module
-------------------------------------------

.. automodule:: pm4py.evaluation.precision.evaluator
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.evaluation.precision.parameters module
--------------------------------------------

.. automodule:: pm4py.evaluation.precision.parameters
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.evaluation.precision.utils module
---------------------------------------

.. automodule:: pm4py.evaluation.precision.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.evaluation.precision
   :members:
   :undoc-members:
   :show-inheritance:
